@@ -352,7 +352,7 @@ Q_SIGNALS:
 protected:
     friend class KCupsRequest;
 
-    virtual void run() override;
+    void run() override;
     bool readyToStart();
     bool retry(const char *resource, int operation) const;
     ReturnArguments request(const KIppRequest &request, ipp_tag_t groupTag = IPP_TAG_ZERO) const;
@@ -363,8 +363,8 @@ private slots:
     void cancelDBusSubscription();
 
 protected:
-    virtual void connectNotify(const QMetaMethod &signal) override;
-    virtual void disconnectNotify(const QMetaMethod &signal) override;
+    void connectNotify(const QMetaMethod &signal) override;
+    void disconnectNotify(const QMetaMethod &signal) override;
     QString eventForSignal(const QMetaMethod &signal) const;
 
 private:
